The data file `f_12_79.dat` contains numerical values of the functions
$F_{1,2}^{7,9}$ computed with the C++ code provided in the source of
http://arxiv.org/abs/arXiv:0810.4077. It has the form

muh z sh F_17re F_17im F_19re F_19im F_27re F_27im F_29re F_29im
